<?php

namespace Drupal\webpack;

/**
 * Interface WebpackConfigBuilderInterface.
 */
interface WebpackConfigBuilderInterface {

  /**
   * Builds webpack config.
   *
   * @param array $context
   *  The build context. Possible keys:
   *   - 'command' => command triggered the generation ['serve' | 'build'].
   *   - 'library' => The target library definition.
   *
   * @param string $outputDir
   *   An output directory.
   * @param string $outputNamePattern
   *   A pattern to use for output files.
   * @param String[]|null $entrypoints
   *   An array of entrypoints. Defaults to all available webpack JS files.
   *
   * @return array
   *  The webpack config.
   *
   * @throws \Drupal\webpack\WebpackConfigNotValidException
   *  If the config is not valid.
   */
  public function buildWebpackConfig($context, $outputDir, $outputNamePattern = '[name].bundle.js', $entrypoints = NULL);

  /**
   * Writes the webpack config to a temp dir.
   *
   * @param array $config
   *   The config to write.
   *
   * @return false|string
   *  The path to the config file.
   *
   * @throws \Drupal\webpack\WebpackConfigWriteException
   *  If the config cannot be written.
   */
  public function writeWebpackConfig($config);

  /**
   * Returns the path to the build output directory.
   *
   * @return string
   *  The path to the build output directory.
   */
  public function getOutputDir();

  /**
   * Returns path to an output file for given library.
   *
   * @param array $library
   *   Target library's definition.
   *
   * @return mixed
   *  Path to the output file.
   *
   * @throws \Drupal\webpack\WebpackNotAWebpackLibraryException
   *  If the library is not a webpack library.
   * @throws \Drupal\webpack\WebpackSingleLibraryInvalidNumberOfJsEntrypointsException
   *  If the library has more than one JS entrypoint.
   */
  public function getSingleLibOutputFilePath($library);

}
